<?php

global $register_text;
$register_text = array (

'registernewuser'	=>	'Registreer nieuwe gebruiker',
'requiredfields'	=>	'Vereiste velden zijn gemarkeerd met een a',
'username'			=>	'Gebruikersnaam',
'password'			=>	'Wachtwoord',
'confirmpass'		=>	'Bevestig wachtwoord',
'realname'			=>	'Echte naam',
'emailaddress'		=>	'Email Address',
'jabberid'			=>	'Jabber ID',
'notifications'		=>	'Berichten',
'none'				=>	'Geen',
'email'				=>	'Email',
'jabber'			=>	'Jabber',
'note'				=>	'<b>Opmerking:</b>  U krijgt een bevestigingscode voordat uw account aangemaakt wordt. Deze code wordt verzonden naar uw gekozen berichttype hierboven.  ALS U VALSE GEGEVENS INVULT, ONTVANGT U UW CODE NIET.',
'sendcode'			=>	'Verzend code!',
'entercode'			=>	'Uw bevestigingscode is verzonden volgens uw gekozen berichttype.  Als u dit ontvangt, typ dit hieronder.  Typ ook uw gewenste wachtwoord.',
'confirmationcode'	=>	'Bevestigingscode',
'registeraccount'	=>	'Registreer deze account',
'registererror'		=>	'Verzeker u ervan dat u alle vereiste velden ingevuld hebt en dat u de correcte details voor uw gewenste berichttype ingevuld hebt.',
'usernametaken'		=>	'Die gebruikersnaam is reeds in gebruik.  U zal een andere naam moeten kiezen.',
'goback'			=>	'Ga terug en voer uit.',
'noticefrom'		=>	'Bericht van',
'addressused'		=>	'Dit adres is gebruikt voor een Flyspray account.  Als u dit bericht niet verwacht, gelieve het dan te verwijderen.  Uw bevestigingscode is:',

// Added in version 0.9.7
'badmagic'              =>      'Dit is een ongeldige magische sleutel! Weet je zeker dat deze sleutel in je notificatie bericht stond?',

);
?>
